setGeneric("PDM",function(data,max.Layers=4,params){
	standardGeneric("PDM")
})

setMethod("PDM", signature(data="matrix"), function(data,max.Layers=4,params){
	if (!missing(params)){
		data <- new("PDMlayers",x=data,params)
	} else {
		data <- new("PDMlayers",x=data)
	}
	PDM(data,max.Layers)
})

setMethod("PDM", signature(data="data.frame"), function(data,max.Layers=4,params){
	if (!missing(params)){
		data <- new("PDMlayers",x=data,params)
	} else {
		data <- new("PDMlayers",x=data)
	}
	PDMstep(data,max.Layers)
})

setMethod("PDM", signature(data="PDMlayers"), function(data,max.Layers=4,params){
	if (!missing(params)){
		data@params[names(params)] <- params
	}
	layer <- 0
	repeat{
		# x <- t(data@scrubbed) # to operate on rows
		x <- data@scrubbed
		pars <- data@params
		layer <- layer+1
		cat("Computing layer",layer,"...\n")
		
		EigLap <- .getEigLapFromData(x, pars$distanceFn, pars$sigma, pars$norm)	

		# ok, first test: is there structure here, by comparison to resampled data?	
	
		nullSpect <- .resample.spectra(x, pars$resample.runs, pars$resample.by, pars$distanceFn, pars$sigma, pars$norm)
		sigEigvals <- .getSignificantEigvals(EigLap$values,nullSpect,pars$compare)

		if (length(sigEigvals)<2) {		
			cat("Partition failure in layer ",layer,": no structure compared to null data; stopping with previous layer.\n")
			break()
		}

		# next: how many clusters?
		if (is.numeric(data@params$k)) {
			k <- data@params$k
		} else {
			k <- switch(data@params$k[1],
				"BIC" = .get.kClusts(EigLap$vectors[,2]),
				"NsigEigvals" = length(sigEigvals)
			)
		}	
		if (!is.numeric(k)){
			stop("k must be either numeric, \"BIC\", or \"NsigEigvals\".")
		}
	
		# how many dimentions in the embedding?	
		if (is.numeric(data@params$l)) {
			space <- 1:data@params$l
		} else {
			space <- switch(data@params$l[1],
				"sigEigvals" = sigEigvals,
				"k" = 1:k,
				"double.k" = 1:(2*k),
				sigEigvals
			)
		}	

		layerSpect <- new("layerSpectra",
			embedding = EigLap$vectors[,space,drop=F],
			spectrum = EigLap$values,
			refSpectrum = nullSpect$refSpectrum,
			refGaps = nullSpect$refGaps
		)
	
		# if k.clusts is less than 2, clustering is meaningless -- eject with data for diagnostic plots
		
		if (k<2) {
			cat("Fewer than two clusters at layer ",layer,"; stopping at previous layer.\n") 
			clusters <- rep(1,ncol(x))
			scrubbed <- matrix()
		} else {
			clusters <- kmeans(layerSpect@embedding, centers=k, nstart=40)[[1]]
			scrubbed <- .getScrubbed(x,clusters,pars$scrubOnProjectionFailure)
		}
		
		data@clusters[,paste("layer",layer,sep=".")] <- clusters
		# data@params #as-is
		data@scrubbed <- scrubbed
		data@PDMspectra[[paste("layer",layer,sep=".")]] <- layerSpect

		if ((layer>=max.Layers)|(length(scrubbed)<=1)){break()}
	}		
	return(data)
})

		
