setClass("layerSpectra",representation(
	embedding="matrix", # embedded data
	spectrum="vector", # spectrum
	refSpectrum="vector", # 0.05 quantile of resampled spectrum
	refGaps="vector" # 0.95 quantile of resampled spectral gaps
))



setClass("PDMlayers", representation(
	clusters="data.frame", # cluster assignment, one column per layer
	params="list", # what params did we start with?
	scrubbed="matrix", # scrubbed data
	PDMspectra="list" # list of layerSpectra, one per layer
))

setMethod("initialize","PDMlayers", function(.Object,x,params){
	# set default parameters and substitute any from the user
	pars <- list( # default parameters
		distanceFn=correlationDist,
		sigma=1,
		norm=c("symmetric","rowsum","none"),
		resample.runs=40,
		resample.by=c("distances","rows"),
		compare=c("fiedgap","fiedval","gaps","vals"),
		k=c("BIC","NsigEigvals"),
		l=c("sigEigvals","k","double.k"),
		scrubOnProjectionFailure=FALSE
	)
	if (!missing(params)){
		pars[names(params)] <- params
	}
	clusterInit <- data.frame(1:ncol(x))[,FALSE]
	rownames(clusterInit) <- colnames(x) 
	.Object@clusters <- clusterInit
	.Object@params <- pars
	.Object@scrubbed <- as.matrix(x)
	.Object@PDMspectra <- list()
	return(.Object)
})	

setMethod("show",
	signature(object="PDMlayers"), 
	function (object) {
		cat("\nPDMlayers object with:")
		cat("\nLayers: ",length(object@PDMspectra))
		cat("\nSamples: ",nrow(object@clusters))
		cat("\nLayer cluster assignments (first 10 samples):\n")
		show(object@clusters[1:min(nrow(object@clusters),10),])
		cat("\n ... use \"clusters()\" to get complete clusters.\n")
		cat("\nAvailable slots:\n", slotNames(object), "\n", sep = " ")
	}
)

setGeneric("clusters",function(object){
	standardGeneric("clusters")
})
setMethod("clusters", 
	signature(object="PDMlayers"),
	function(object){
		object@clusters
	}
)

setGeneric("spectra",function(object,...){
	standardGeneric("spectra")
})
setMethod("spectra", 
	signature(object="PDMlayers"),
	function(object,layer){
		if (missing(layer)){
			layer <- length(object@PDMspectra)
		}
		object@PDMspectra[[layer]]
	}
)


setGeneric("spectrum",function(object,...){
	standardGeneric("spectrum")
})
setMethod("spectrum", 
	signature(object="layerSpectra"),
	function(object){
		object@spectrum[-1]
	}
)
setMethod("spectrum", 
	signature(object="PDMlayers"),
	function(object,layer){
		if (missing(layer)){
			layer <- length(object@PDMspectra)
		}
		spectrum(spectra(object,layer))
	}
)


setGeneric("embedding",function(object,...){
	standardGeneric("embedding")
})
setMethod("embedding", 
	signature(object="layerSpectra"),
	function(object){
		object@embedding[,-1]
	}
)
setMethod("embedding", 
	signature(object="PDMlayers"),
	function(object,layer){
		if (missing(layer)){
			layer <- length(object@PDMspectra)
		}
		embedding(spectra(object,layer))
	}
)


setGeneric("fiedlerVec",function(object,...){
	standardGeneric("fiedlerVec")
})
setMethod("fiedlerVec", 
	signature(object="layerSpectra"),
	function(object){
		object@embedding[,2]
	}
)
setMethod("fiedlerVec", 
	signature(object="PDMlayers"),
	function(object,layer){
		if (missing(layer)){
			layer <- length(object@PDMspectra)
		}
		fiedlerVec(spectra(object,layer))
	}
)

