setMethod("plot", 
	signature(x="layerSpectra"),
	function(x,y,Nvals=40,...){
		
		spectrum <- x@spectrum
		gaps <- spectrum[-1]-spectrum[-length(spectrum)]
		nullSpect <- list(refSpectrum=x@refSpectrum,refGaps=x@refGaps)
	
		xlim <- c(0,min(Nvals,length(spectrum)))

		spect.pch <- rep(1,length(spectrum))
		spect.pch[.getSignificantEigvals(spectrum,nullSpect,"fiedval")] <- 19
		spect.col <- rep(1,length(spectrum))
		spect.col[.getSignificantEigvals(spectrum,nullSpect,"vals")] <- 2

		gap.pch <- rep(1,length(gaps))
		gap.pch[.getSignificantEigvals(spectrum,nullSpect,"fiedgap")] <- 19
		gap.col <- rep(1,length(gaps))
		gap.col[.getSignificantEigvals(spectrum,nullSpect,"gaps")] <- 2
			
		plot(spectrum[-1], 
			main="Spectrum",
			col=spect.col[-1],
			pch=spect.pch[-1],
			xlim=xlim,
			ylab="Eigenvalues"
		)
		mtext("(0-eigenvalue omitted)",cex=0.8)
		abline(h=nullSpect$refSpectrum[2],col=5)
		points(nullSpect$refSpectrum[-1],col=3,pch=95)

		plot(gaps[-1], 
			main="Spectral gaps",
			col=gap.col[-1],
			pch=gap.pch[-1],
			xlim=xlim,
			ylab="Eigengaps"
		)
		abline(h=nullSpect$refGaps[2],col=5)
		points(nullSpect$refGaps[-1],col=3,pch=95)
		mtext("(first eigengap omitted)",cex=0.8)
	}
)

setMethod("plot", 
	signature(x="PDMlayers"),
	function(x,y,Nvals=40,...){
		#def.par<-par(no.readonly=TRUE)
		if ( interactive() & dev.interactive(orNone=TRUE) & !par()$ask & length(x@PDMspectra)>1){
			ask <- readline(paste("Caution: attempting to plot",ncol(x),"layers to interactive device without pause.\nSet par(ask=TRUE)? y/n/q > "))
			while (!substr(ask,1,1)%in%c("y","n","Y","N","q","Q")){
				ask <- readline(paste("Please answer y/n/q > "))
			}
			if (substr(ask,1,1)%in%c("q","Q")){
				return("ok, stopping")
			}
			if (substr(ask,1,1)%in%c("y","Y")){
				par(ask=TRUE)
			}
		} else { if (!(interactive()&dev.interactive(orNone=TRUE))) {par(ask=FALSE)} }
		for(layer in 1:length(x@PDMspectra)){
			plot(x,layer,Nvals,...)
		}
	}
)

setMethod("plot", 
	signature(x="PDMlayers",y="numeric"),
	function(x,y,Nvals=40,main,...){
		if (!y%in%1:ncol(clusters(x))){
			stop("y must be a layer between 1 and ",ncol(clusters(x)))
		}

		def.par<-par(no.readonly=TRUE)
		
		nf <- layout(matrix(c(1,0,2,0,4,3),nc=2,byrow=T),c(5,1),c(2,2,3))
		
		layer <- y
		
		# PLOT SPECTRA
		par(mar=c(1,5,5,1))
		plot(spectra(x,layer),Nvals)

		# PLOT FIEDLER
		fiedler <- fiedlerVec(spectra(x,layer))
		clusters <- clusters(x)[,layer]
		clust.col <- rainbow(max(clusters),start=0,end=2/3)[clusters]
				
		par(mar=c(5,0,5,1))
		dens <- density(fiedler,na.rm=T)
		plot(dens$y,dens$x,type="l",ylim=range(fiedler),axes=F, xlab="")
		mtext("density",cex=0.8)
		axis(1)
		abline(h=0)

		par(mar=c(5,5,5,1))
		plot(fiedler,
			main=paste("Fiedler Vector and Cluster Assignment"), 
			xlab="Sample index",
			ylab="Fiedler vector",
			ylim=range(fiedler),
			col=clust.col,
			...
		)
		mtext("Color denotes cluster assignment",cex=0.8)
		if (missing(main)){
			mtext(paste("LAYER",layer),side=3,line=-1.5,cex=1,outer=T)
		} else {
			mtext(paste(main,"- LAYER",layer),side=3,line=-1.5,cex=1,outer=T)
		}
		abline(h=0)
		
		par(def.par)
	}
)



