# LOAD SOME EXAMPLE DATA
data(golub1999)
set.seed(100) # just to make the demo reproducible

# golub1999 is a list with gene expressions and phenotypes.
# Let's take a peek:
names(golub1999)
dim(golub1999$expr)
length(golub1999$pheno)
golub1999$expr[1:5,1:4]
golub1999$pheno

# RUN PDM WITH DEFAULTS

pdm.golub <- PDM(golub1999$expr)
pdm.golub

# look at the clusters in PDM layers
table(clusters(pdm.golub)$layer.1, golub1999$pheno)
table(clusters(pdm.golub)$layer.2, golub1999$pheno)
# combined layer.1 and layer.2 clusters:
combinedLayers <- paste("l1-", clusters(pdm.golub)$layer.1,
                        ".l2-", clusters(pdm.golub)$layer.2, sep="")
table(combinedLayers, golub1999$pheno)

# grab the spectrum from the 1st layer
spectrum(pdm.golub, layer=1)
# look at the size of the embedded data from the 2nd layer
dim(embedding(pdm.golub, layer=2))

# plot all layers with defaults (you may need to resize the window):
plot(pdm.golub, main="Golub1999")

# plot only the first layer, with pch given by sample phenotype
#   A = AML, B = B-cell ALL, T = T-cell ALL
plot(pdm.golub, 1, pch=golub1999$pheno, main="with phenotypes")

# drop vertical lines separating phenotypes...
# first find the indices where the phenotypes change:
separateAt <- which(
  golub1999$pheno[-length(golub1999$pheno)]!=golub1999$pheno[-1]
)
# then plot the lines:
abline(v=separateAt+0.5, col="grey")


# RUN PDM, OVER-RIDING DEFAULTS

# force 3 clusters and set sigma=0.5 through params, running just one layer
pdm.golub.k3 <- PDM(golub1999$expr, max.Layers=1, params=list(sigma=0.5, k=3))
plot(pdm.golub.k3, pch=golub1999$pheno, main="Golub PDM: k=3, sigma=0.5")



# attempt to run another layer from the previous one, now forcing 2 clusters: 
PDM(pdm.golub.k3, max.Layers=1, params=list(sigma=0.5, k=2))

# using a different distance function
pdm.golub.euc <- PDM(golub1999$expr, params=list(distanceFn=euclideanDist))
plot(pdm.golub.euc, pch=golub1999$pheno, main="Golub PDM: Euclidean dist")

# an example of a user-defined distance function
maxDist <- function(x){
	# need to transpose x to allow dist() to operate column-wise:
	d <- as.matrix(dist(t(x), method = "euclidean"))
	# scale on [0,1]
	d <- d/max(d)
	return(d)
}
pdm.golub.max <- PDM(golub1999$expr, params=list(distanceFn=maxDist))
plot(pdm.golub.max, pch=golub1999$pheno, main="Golub PDM: maxDist dist")

