\name{PDM}
\alias{PDM}
\alias{PDM,matrix-method}
\alias{PDM,data.frame-method}
\alias{PDM,PDMlayers-method}
\title{PDM}
\description{Function for computing the PDM layers}

\usage{
PDM(data,max.Layers=4,params)
}

\arguments{
   \item{data}{A matrix or data frame containing the samples (columns) to be clustered. Alternatively, a \code{\linkS4class{PDMlayers}} object output from a previous PDM run may be used; in this case, the scrubbed data will be clustered.}
	\item{max.Layers}{Maximum number of layers to return; default is 4. (PDM may return fewer; see details below).}
	\item{params}{A \code{\link[base]{list}} containing settable parameters for the spectral clustering algorithm; see details below.}
}

\value{A \code{\linkS4class{PDMlayers}} object with at most maxLayers layers contining the clustering output.  See  \code{\linkS4class{PDMlayers}}.}

\details{
The PDM function carries out iterated spectral clustering and ``scrubbing'' (projection of data onto centroids and returning the residuals) steps, yielding ``layers'' of clusters.  The procedure is carried out until one of three criteria is met: either maxLayers is reached; the scrubbed (residual) data has spectral characteristics indistinguishable from noise (``partition failure''); or the centroids are not independent (``projection failure''). 

The parameters for the spectral clustering procedure may be set by supplying them as a list to argument \code{params}.  The settable parameters are:
\describe{
\item{distanceFn}{A function (named or anonymous) for calculating the pairwise distances between all columns in \code{data}. For user-supplied distance functions, note that distances should be scaled to lie on [0,1]. Refer to \code{\link{distanceFn}} for examples and two supplied functions.  Default is \code{\link{correlationDist}}.}
\item{sigma}{The scaling parameter for the Gaussian transformation. Should be non-negative; 0 yields untransformed data.  Default is \code{sigma=1}.}
\item{resample.runs}{Number of resamplings used to generate the reference distribution of the graph spectra. Default is \code{resample.runs=40}.}
\item{resample.by}{The reference distribution of the graph spectra may be obtained either through resampling the distances (\code{"distances"}) or the covariates/rows in the original data (\code{"rows"}); default is \code{"distances"}.}
\item{compare}{How should the threshold for significant eigenvalues be set?  \code{"fiedgap"} compares the spectral gaps (\eqn{\lambda_i - \lambda_{i-1}}) to the 0.95 percentile  gap of the Fiedler value in the resampled data; \code{"gaps"}  compares the spectral gaps  to the corresponding 0.95 percentile of gaps  in the resampled data; \code{"fiedval"} compares the spectra (\eqn{\lambda_i}) to the 0.05 percentile Fiedler value (\eqn{\lambda_1})  in the resampled data, and \code{"vals"} compares the spectra to the 0.05 percentile spectra in the resampled data. Default is \code{"fiedgap"}.}
\item{k}{Numeric number of clusters or the method to automatically compute it: \code{"BIC"} fits Gaussian mixture models to the Fiedler vector and returns the number of components with best BIC; \code{"NsigEigVals"} takes as the number of clusters the number of significant eigenvalues obtained from the resampling.  Default is \code{"BIC"}.}
\item{l}{Dimensions for the embedding or the method to automatically compute dimensions: \code{"sigEigvals"} uses the vectors with significant eigenvalues obtained from the resampling; \code{"k"} takes the first $k$ vectors, where $k$ is the number of clusters (either provided or automatically determined as above); \code{"double.k"} takes the first $2k$ vectors.  If \code{l} is numeric, the first $l$ vectors are used.  Default is \code{"sigEigvals"}.}
\item{scrubOnProjectionFailure}{Boolean: return scrubbed data even if cluster centroids are not independent?  Default \code{FALSE}.}
}}

\examples{
data(golub1999)
pdm.golub <- PDM(golub1999$expr)
pdm.golub
\dontrun{plot(pdm.golub,pch=golub1999$pheno)}

# force 3 clusters and set sigma=0.5 through params, returning at most 1 layer:
pdm.golub.k3 <- PDM(golub1999$expr,1, params=list(sigma=0.5,k=3))
\dontrun{plot(pdm.golub.k3,pch=golub1999$pheno)}

}


\keyword{cluster}
