\name{PDMlayers-class}
\docType{class}
\alias{PDMlayers}
\alias{PDMlayers-class}
\alias{show,PDMlayers-method}

\title{"PDMlayers" class and methods for PDM output}

\description{
This class holds PDM output data, including the clustering results for
each layer, the spectra and embedding for each layer, the PDM parameters
used, and the current scrubbed data.
}

\section{Slots}{
\describe{
    \item{\code{clusters}:}{Data frame of cluster assigments: one column per layer, one row per sample.}
    \item{\code{params}:}{The parameters fed to PDM for the spectral clustering; see \code{\link{PDM}}.}
    \item{\code{PDMspectra}:}{A list of \code{\linkS4class{layerSpectra}} objects containing the spectral data for each layer.}
	\item{\code{scrubbed}:}{A numeric matrix containing the "scrubbed" data after the most recent layer (may be NA; see \code{\link{PDM}}).}
}
}

\section{Methods}{
\describe{
\item{show}{\code{signature(object = "PDMlayers")}: shows a summary of the PDMlayers object, including the number of layers, number of samples, cluster assignments for first ten samples, and slot names.}
\item{\code{\link{clusters}}:}{ extracts a data frame with the cluster assignments from each layer: one column per layer, one row per sample.}
\item{\code{\link{spectra}}:}{ extracts the \code{\linkS4class{layerSpectra}} object containing the spectral data for the specified layer.  If no layer is specified, the last layer is used.}
\item{\code{\link{spectrum}}:}{ extracts the spectrum (eigenvalues; 0-eigenvalue dropped) for the specified layer.  If no layer is specified, the last layer is used.}
\item{\code{\link{fiedlerVec}}:}{ extracts the Fiedler vector for the specified layer.  If no layer is specified, the last layer is used.}
\item{\code{\link{embedding}}:}{ extracts the complete dimension-reduced Laplacian eigenmap embedding for the specified layer.  If no layer is specified, the last layer is used.}
\item{\code{\link{plot}}:}{ Plots the spectrum, spectral gaps, and fielder vector for the y-th layer.  See \code{\link{plot}} for details.}
}
}

\examples{
data(golub1999)
pdm.golub <- PDM(golub1999$expr)
pdm.golub
}
\keyword{classes}

