\name{plot}
\alias{plot}
\alias{plot,PDMlayers-method}
\alias{plot,PDMlayers,ANY-method}
\alias{plot,PDMlayers,numeric-method}
\title{Plot PDMlayers output}
\description{Plot spectra, Fiedler vector, and clustering for PDM layers}

\usage{
\S4method{plot}{PDMlayers,numeric}(x,y,Nvals=40,main,...)
\S4method{plot}{PDMlayers}(x,Nvals=40,main,...)
}

\arguments{
   \item{x}{A \code{\linkS4class{PDMlayers}} object output from \code{\link{PDM}}.}
	\item{y}{Optionally, the number of the layer to plot. If \code{y} is not specified, each layer will be plotted.}
	\item{Nvals}{Most number of eigenvalues/eigengaps to plot?  Default is maximum of 40.} 
	\item{main}{An optional character string for the main title.}
	\item{...}{Additional arguments to \code{\link[graphics]{plot}}; see details.}
}

\details{
This function attemps to produce a three-panel plot for a PDM layer:
\describe{
\item{Top panel:}{Spectrum (eigenvalues) plotted as circles (up
to the \code{Nvals}'th one and omitting the trivial 0-valued first
eigenvalue); 0.05 quantile of the resampled null distributions for
the eigenvalues plotted as green dashes; 0.05 quantile of the
resampled null distributions for the Fiedler value (first non-0
eigenvalue) given as a cyan line. Fill of circles denotes 
significance WRT the null Fiedler value; color denotes significance
WRT the null spectrum.}
\item{Middle panel:}{Spectral gaps plotted as circles (up to the
\code{Nvals}'th one, and omitting the trivial first one); 0.95
quantile of the resampled null distributions for the eigengaps
plotted as green dashes; 0.95 quantile of the resampled null
distributions for the Fiedler gap given as a cyan line.  Fill of
circles denotes significance WRT the null Fiedler gap; color denotes
significance WRT the null eigengaps.}
\item{Bottom panel:}{Fiedler vector values (y-axis) vs. sample index
for each sample, along with the Fiedler vector distribution shown
as a marginal plot on the right. Color of the samples indicates the
cluster assignment for that sample in the layer shown. The marginal
plot is useful as a diagnostic of the number a clusters; the number
of components that best fit this distribution is taken as the number
of clusters in PDM.} 
}

The \code{...} argument may be used to supply additional arguments
to the plot for the \strong{bottom left} Fiedler vector plot, eg,
\code{pch}; see \link[graphics]{plot} for more information. However, note that
you may not over-ride the colors with \code{col} in this function!
(To plot the spectrum or Fiedler vector in a more flexibly user-defined
way, use \code{\link{fiedlerVec}} to obtain the Fiedler vector and
\code{\link{spectra}}/\code{\link{spectrum}} to extract the spectra.)

The current graphics panel after the plot is finished will be the
one on the bottom left, permitting the addition of lines or labels
as desired by the user.  }

\examples{
data(golub1999)
pdm.golub <- PDM(golub1999$expr)
\dontrun{
# default plots for two layers
plot(pdm.golub,main="Golub1999 PDM")
# plot of first layer, with pch given by sample phenotype
# A = AML, B = B-cell ALL, T = T-cell ALL
plot(pdm.golub,1,main="Golub1999 PDM",pch=golub$pheno)
# drop vertical lines separating phenotypes
# first find the indices where the phenotypes change:
separateAt <- which(golub1999$pheno[-length(golub1999$pheno)]!=golub1999$pheno[-1]
abline(v=separateAt+0.5,col="grey")
}
}

\keyword{graphics}
